"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SlackIncomingWebhook = void 0;
const GenericFunctions_1 = require("./GenericFunctions");
const WebhookDescription_1 = require("./WebhookDescription");
class SlackIncomingWebhook {
    constructor() {
        this.description = {
            displayName: 'Slack Incoming Webhook',
            name: 'slackIncomingWebhook',
            icon: 'file:slack.svg',
            group: ['transform'],
            version: 1,
            subtitle: '={{$parameter["operation"] + ": " + $parameter["resource"]}}',
            description: 'Send messages to Slack using the legacy incoming Webhooks add-on',
            defaults: {
                name: 'Slack Incoming Webhook',
                color: '#0b3d91',
            },
            inputs: ['main'],
            outputs: ['main'],
            credentials: [
                {
                    name: 'slackIncomingWebhookApi',
                    required: true,
                },
            ],
            properties: [
                {
                    displayName: 'Operation',
                    name: 'operation',
                    type: 'options',
                    noDataExpression: true,
                    options: [
                        {
                            name: 'Send Message',
                            value: 'sendMessage',
                            description: 'Send Message to Slack',
                            action: 'Send message to slack',
                        },
                    ],
                    default: 'sendMessage',
                },
                ...WebhookDescription_1.webhookOperations,
            ],
        };
    }
    async execute() {
        const items = this.getInputData();
        const returnData = [];
        let responseData;
        for (let i = 0; i < items.length; i++) {
            try {
                const operation = this.getNodeParameter('operation', i);
                const options = this.getNodeParameter('options', i);
                if (operation === 'sendMessage') {
                    const body = {};
                    const message = this.getNodeParameter('message', i);
                    body.text = message;
                    if (options.name !== undefined) {
                        body.username = options.name;
                    }
                    if (options.icon !== undefined) {
                        body.icon_emoji = options.icon;
                    }
                    responseData = await GenericFunctions_1.slackWebhookRequest.call(this, 'POST', body);
                    responseData = { 'status': responseData };
                }
                if (Array.isArray(responseData)) {
                    returnData.push.apply(returnData, responseData);
                }
                else {
                    returnData.push(responseData);
                }
            }
            catch (error) {
                if (this.continueOnFail()) {
                    returnData.push({ error: error.message });
                    continue;
                }
                throw error;
            }
        }
        return [this.helpers.returnJsonArray(returnData)];
    }
}
exports.SlackIncomingWebhook = SlackIncomingWebhook;
//# sourceMappingURL=SlackIncomingWebhook.node.js.map